@@ -8,6 +8,7 @@ use icu_locid::LanguageIdentifier;
 use serde::Deserialize;
 
 #[derive(Display, Debug)]
+#[non_exhaustive]
 pub enum Error {
     #[displaydoc("Cargo Error: {0}")]
     Cargo(cargo_metadata::Error),
@@ -34,6 +35,7 @@ impl From<serde_json::Error> for Error {
 }
 
 #[derive(Debug, Deserialize)]
+#[non_exhaustive]
 pub struct PackageMetadata {
     pub locales: Vec<LanguageIdentifier>,
     pub cldr_json_glob: Vec<String>,
@@ -48,7 +50,7 @@ impl PackageMetadata {
         for pattern in self.cldr_json_glob.iter() {
             if pattern.contains("$LOCALES") {
                 for locale in self.locales.iter() {
-                    let locale_str = writeable::Writeable::writeable_to_string(locale);
+                    let locale_str = writeable::Writeable::write_to_string(locale);
                     paths.push(pattern.replace("$LOCALES", &locale_str));
                 }
                 // Also add "root" for older CLDRs
@@ -63,6 +65,7 @@ impl PackageMetadata {
 }
 
 #[derive(Debug)]
+#[non_exhaustive]
 pub struct PackageInfo {
     pub target_directory: Utf8PathBuf,
     pub package_metadata: PackageMetadata,
@@ -103,6 +106,6 @@ fn test_metadata() {
     assert!(package_info
         .package_metadata
         .locales
-        .contains(&(LanguageIdentifier::und())));
+        .contains(&(LanguageIdentifier::UND)));
     assert!(package_info.package_metadata.locales.len() > 10);
 }
